@@ -9,6 +9,7 @@ from boto3.session import Session
 
 from mypy_boto3_builder.cli_parser import Namespace, parse_args
 from mypy_boto3_builder.constants import BUILDER_REPO_URL, DUMMY_REGION, Product, ProductLibrary
+from mypy_boto3_builder.generators.aioboto3_generator import AioBoto3Generator
 from mypy_boto3_builder.generators.aiobotocore_generator import AioBotocoreGenerator
 from mypy_boto3_builder.generators.base_generator import BaseGenerator
 from mypy_boto3_builder.generators.boto3_generator import Boto3Generator
@@ -82,6 +83,23 @@ def get_available_service_names(session: Session) -> list[ServiceName]:
     return result
 
 
+def get_generator_cls(product: Product) -> type[BaseGenerator]:
+    """
+    Get Generator class for a product.
+
+    Raises:
+        ValueError -- If product is not supported.
+    """
+    library = product.get_library()
+    if library == ProductLibrary.boto3:
+        return Boto3Generator
+    if library == ProductLibrary.aiobotocore:
+        return AioBotocoreGenerator
+    if library == ProductLibrary.aioboto3:
+        return AioBoto3Generator
+    raise ValueError(f"Unknown product library: {library}")
+
+
 def generate_product(
     product: Product,
     args: Namespace,
@@ -99,11 +117,8 @@ def generate_product(
         service_names -- Selected service names
         master_service_names -- Service names included in master
     """
-    generator_cls = {
-        ProductLibrary.boto3: Boto3Generator,
-        ProductLibrary.aiobotocore: AioBotocoreGenerator,
-    }[product.get_library()]
-    generator: BaseGenerator = generator_cls(
+    generator_cls = get_generator_cls(product)
+    generator = generator_cls(
         service_names=service_names,
         master_service_names=master_service_names,
         session=session,
